@@ -13,11 +13,11 @@ def get_location(request):
 class LocationMiddleware(object):
 
     def process_request(self, request):
-        # Don't detect location, until we request it implicitly
+        """ Don't detect location, until we request it implicitly """
         request.location = SimpleLazyObject(lambda: get_location(request))
 
     def process_response(self, request, response):
-        # Do nothing, if process_request never completed (redirect)
+        """ Do nothing, if process_request never completed (redirect)"""
         if not hasattr(request, 'location'):
             return response
 
