@@ -12,5 +12,7 @@ else:
 
 SECRET_KEY = '_'
 ROOT_URLCONF = 'test_app.urls'
-INSTALLED_APPS = ('django_nose', 'django_geoip', 'test_app')
-TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
\ No newline at end of file
+INSTALLED_APPS = ('django_geoip', 'test_app')
+
+if django.VERSION[:2] < (1, 6):
+    TEST_RUNNER = 'discover_runner.DiscoverRunner'
\ No newline at end of file
